/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Injectable } from '@angular/core';
import { AppConfigService } from "../../env/app-config.service";
import {BehaviorSubject, Observable, Subscription} from "rxjs";
import {ResultType} from "../model/result-type";

/*
 This service is for communicating facets between all filters and archive-search.
 The filters themselves are dynamically generated, so we can't bind facets through the template.
 Facets are retrieved from the server in the env/app-config.service.
 The archive-search.component actually subscribes to appConfig, gets the results and sends them here.
 All the filters pull from here. Because archive-search loads the filters, this should be all set before
 anything else needs it.
 */

@Injectable({
  providedIn: 'root'
})
export class FacetsService {

  private facets: any;

  getFacets(){
    return this.facets;
  }

  setFacets(facets:any){
    this.facets = facets;
  }

  getFacet(name:string){
    if(this.facets && this.facets.hasOwnProperty(name)){
      return this.facets[name];
    } else {
      return false;
    }
  }

}
